@@ -6,7 +6,7 @@ use Config;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build and make available libffi
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 sub libs
 {
@@ -26,7 +26,7 @@ sub libs
     $libs .= ' /usr/lib/libpthread.a';
   }
   
-  if($^O eq 'MSWin32' && $Config{cc} =~ /cl(\.exe)?$/i)
+  if($^O eq 'MSWin32' && $Config{ccname} eq 'cl')
   {
     $libs =~ s{-L}{/LIBPATH:}g;
     $libs =~ s{-l([A-Za-z]+)}{$1.LIB}g;
@@ -47,6 +47,13 @@ sub cflags
     my $working_dir = $class->config('working_directory');
     $cflags = "-I$working_dir/include";
   }
+
+  if($class->install_type eq 'share'
+  && $^O eq 'MSWin32'
+  && $Config{ccname} eq 'cl')
+  {
+    $cflags .= " -DFFI_BUILDING";
+  }  
   
   $cflags;
 }
@@ -66,7 +73,7 @@ Alien::FFI - Build and make available libffi
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
